==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnHiddenChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnHiddenChangedEventArgsDescription } from "./ColumnHiddenChangedEventArgsDescription";
/**
 * @hidden
 */
export let ColumnHiddenChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnHiddenChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnHiddenChangedEventArgsDescriptionMetadata.a == null) {
                ColumnHiddenChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnHiddenChangedEventArgsDescriptionMetadata.c(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ColumnHiddenChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("IsHidden", "Boolean");
        }
        static d(a) {
            ColumnHiddenChangedEventArgsDescriptionMetadata.b(a);
            a.aa("ColumnHiddenChangedEventArgs", () => new ColumnHiddenChangedEventArgsDescription());
            a.z("ColumnHiddenChangedEventArgs", ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        }
    }
    ColumnHiddenChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnHiddenChangedEventArgsDescriptionMetadata, 'ColumnHiddenChangedEventArgsDescriptionMetadata');
    ColumnHiddenChangedEventArgsDescriptionMetadata.a = null;
    return ColumnHiddenChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnHiddenChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnHiddenChangedEventArgsDescription } from "./ColumnHiddenChangedEventArgsDescription";
/**
 * @hidden
 */
export let ColumnHiddenChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnHiddenChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnHiddenChangedEventArgsDescriptionMetadata.a == null) {
                ColumnHiddenChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnHiddenChangedEventArgsDescriptionMetadata.c(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ColumnHiddenChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("IsHidden", "Boolean");
        }
        static d(a) {
            ColumnHiddenChangedEventArgsDescriptionMetadata.b(a);
            a.ac("ColumnHiddenChangedEventArgs", () => new ColumnHiddenChangedEventArgsDescription());
            a.ab("ColumnHiddenChangedEventArgs", ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        }
    }
    ColumnHiddenChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnHiddenChangedEventArgsDescriptionMetadata, 'ColumnHiddenChangedEventArgsDescriptionMetadata');
    ColumnHiddenChangedEventArgsDescriptionMetadata.a = null;
    return ColumnHiddenChangedEventArgsDescriptionMetadata;
})();
